==> v0.3.tar.gz: photosapi/modules/utils.py <==
from traceback import print_exc
from typing import Any, Union

from ujson import JSONDecodeError, dumps, loads


# Print to stdout and then to log
def logWrite(message: str, debug: bool = False) -> None:
    # save to log file and rotation is to be done
    # logAppend(f'{message}', debug=debug)
    print(f"{message}", flush=True)


def jsonLoad(filepath: str) -> Any:
    """Load json file

    ### Args:
        * filepath (`str`): Path to input file

    ### Returns:
        * `Any`: Some json deserializable
    """
    with open(filepath, "r", encoding="utf8") as file:
        try:
            output = loads(file.read())
        except JSONDecodeError:
            logWrite(
                f"Could not load json file {filepath}: file seems to be incorrect!\n{print_exc()}"
            )
            raise
        except FileNotFoundError:
            logWrite(
                f"Could not load json file {filepath}: file does not seem to exist!\n{print_exc()}"
            )
            raise
        file.close()
    return output


def jsonSave(contents: Union[list, dict], filepath: str) -> None:
    """Save contents into json file

    ### Args:
        * contents (`Union[list, dict]`): Some json serializable
        * filepath (`str`): Path to output file
    """
    try:
        with open(filepath, "w", encoding="utf8") as file:
            file.write(dumps(contents, ensure_ascii=False, indent=4))
            file.close()
    except Exception as exp:
        logWrite(f"Could not save json file {filepath}: {exp}\n{print_exc()}")
    return


def configGet(key: str, *args: str) -> Any:
    """Get value of the config key

    ### Args:
        * key (`str`): The last key of the keys path.
        * *args (`str`): Path to key like: dict[args][key].

    ### Returns:
        * `Any`: Value of provided key
    """
    this_dict = jsonLoad("config.json")
    this_key = this_dict
    for dict_key in args:
        this_key = this_key[dict_key]
    return this_key[key]


def apiKeyInvalid(obj):
    obj.send_response(401)
    obj.send_header("Content-type", "application/json; charset=utf-8")
    obj.end_headers()
    obj.wfile.write(b'{"code":401, "message": "Invalid API key"}')
    return


def apiKeyExpired(obj):
    obj.send_response(403)
    obj.send_header("Content-type", "application/json; charset=utf-8")
    obj.end_headers()
    obj.wfile.write(b'{"code":403, "message": "API key expired"}')
    return

==> v0.5.0.tar.gz: photosapi/modules/utils.py <==
import logging
from pathlib import Path
from traceback import format_exc
from typing import Any, Union

from ujson import JSONDecodeError, dumps, loads

logger = logging.getLogger(__name__)


def jsonLoad(filepath: Union[str, Path]) -> Any:
    """Load json file

    ### Args:
        * filepath (`Union[str, Path]`): Path to input file

    ### Returns:
        * `Any`: Some json deserializable
    """
    with open(filepath, "r", encoding="utf8") as file:
        try:
            output = loads(file.read())
        except JSONDecodeError:
            logger.error(
                "Could not load json file %s: file seems to be incorrect!\n%s",
                filepath,
                format_exc(),
            )
            raise
        except FileNotFoundError:
            logger.error(
                "Could not load json file %s: file does not seem to exist!\n%s",
                filepath,
                format_exc(),
            )
            raise
        file.close()
    return output


def jsonSave(contents: Union[list, dict], filepath: Union[str, Path]) -> None:
    """Save contents into json file

    ### Args:
        * contents (`Union[list, dict]`): Some json serializable
        * filepath (`Union[str, Path]`): Path to output file
    """
    try:
        with open(filepath, "w", encoding="utf8") as file:
            file.write(dumps(contents, ensure_ascii=False, indent=4))
            file.close()
    except Exception as exp:
        logger.error("Could not save json file %s: %s\n%s", filepath, exp, format_exc())
    return


def configGet(key: str, *args: str) -> Any:
    """Get value of the config key

    ### Args:
        * key (`str`): The last key of the keys path.
        * *args (`str`): Path to key like: dict[args][key].

    ### Returns:
        * `Any`: Value of provided key
    """
    this_dict = jsonLoad(Path("config.json"))
    this_key = this_dict
    for dict_key in args:
        this_key = this_key[dict_key]
    return this_key[key]


def apiKeyInvalid(obj):
    obj.send_response(401)
    obj.send_header("Content-type", "application/json; charset=utf-8")
    obj.end_headers()
    obj.wfile.write(b'{"code":401, "message": "Invalid API key"}')
    return


def apiKeyExpired(obj):
    obj.send_response(403)
    obj.send_header("Content-type", "application/json; charset=utf-8")
    obj.end_headers()
    obj.wfile.write(b'{"code":403, "message": "API key expired"}')
    return
